# -*- coding: utf-8 -*-
# Created by makepy.py version 0.5.01
# By python version 3.13.7 (tags/v3.13.7:bcee1c3, Aug 14 2025, 14:15:11) [MSC v.1944 64 bit (AMD64)]
# From type library 'OrgLab980.tlb'
# On Sun Dec 21 14:48:44 2025
class constants:
	OCD_ABORT_IF_EMPTY            =8192       # from enum OCDOPTION
	OCD_APPLY_SIBLINGS            =524288     # from enum OCDOPTION
	OCD_ASK                       =33554432   # from enum OCDOPTION
	OCD_CREATE_MIXED_COL          =64         # from enum OCDOPTION
	OCD_DEL_LINKED_OBJS           =67108864   # from enum OCDOPTION
	OCD_DEL_PARENT_IF_LAST        =134217728  # from enum OCDOPTION
	OCD_DESTRY_DEFAULT            =201326592  # from enum OCDOPTION
	OCD_DIFF_NAME                 =131072     # from enum OCDOPTION
	OCD_ENUM_ADD_SEPARATOR        =524288     # from enum OCDOPTION
	OCD_ENUM_NEXT                 =262144     # from enum OCDOPTION
	OCD_ENUM_NEXT_KEEP_CONSISTENT =256        # from enum OCDOPTION
	OCD_ERROR                     =-2147483648 # from enum OCDOPTION
	OCD_FADEWAY_HINT_SHOW         =32         # from enum OCDOPTION
	OCD_INITDATA                  =8388608    # from enum OCDOPTION
	OCD_KEEP_SN                   =2048       # from enum OCDOPTION
	OCD_LNAME_IF_NOT_GOOD_SNAME   =4096       # from enum OCDOPTION
	OCD_LONG_NAME                 =32768      # from enum OCDOPTION
	OCD_MODIFY                    =1073741824 # from enum OCDOPTION
	OCD_MODIFY_ADD                =4096       # from enum OCDOPTION
	OCD_MODIFY_DEL                =8192       # from enum OCDOPTION
	OCD_NO_CONVERT_IMAGE          =16         # from enum OCDOPTION
	OCD_NO_EVENTS                 =268435456  # from enum OCDOPTION
	OCD_NO_INVALIDATE             =128        # from enum OCDOPTION
	OCD_NO_KEEP_STYLEHOLDER       =16         # from enum OCDOPTION
	OCD_NO_SET_LN                 =131072     # from enum OCDOPTION
	OCD_NO_UPDATE_CELL_REF        =8          # from enum OCDOPTION
	OCD_PROGRESS                  =1048576    # from enum OCDOPTION
	OCD_REPAINT                   =2097152    # from enum OCDOPTION
	OCD_RESERVED_1                =1024       # from enum OCDOPTION
	OCD_RESERVED_2                =512        # from enum OCDOPTION
	OCD_RESET_VIEW                =16384      # from enum OCDOPTION
	OCD_RESTORE                   =4194304    # from enum OCDOPTION
	OCD_STRUCT_MODIFIY            =536870912  # from enum OCDOPTION
	OCD_UNDO                      =16777216   # from enum OCDOPTION
	OCD_UPDATE_PE                 =65536      # from enum OCDOPTION
	OCD_WARNING                   =33554432   # from enum OCDOPTION
	ODISPID_APPLICATION           =272        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_ACTIVEFOLDER      =62         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_ACTIVE_NOTE       =75         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_ACTIVE_PAGE       =74         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_DATARANGE         =58         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_EVALUATE          =80         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_EXIT              =66         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_EXTERENALDLGPAGES =57         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_FINDWKS           =69         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_FIND_GRAPH        =73         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_FIND_MAT_SHEET    =71         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_GET_DATA_TREE     =78         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_GET_FINDER        =77         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_GRAPHPAGES        =52         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_HIDEONCLOSE       =72         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_LAYOUTPAGES       =53         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_LOADPAGE          =79         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_MATRIXPAGES       =55         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_NAME              =65         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_NEWPROJECT        =60         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_NOTES             =56         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_PAGEBASES         =50         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_PAGES             =51         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_PATH              =68         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_PROJINFO          =61         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_PROJ_SEARCH       =76         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_REMINDERMSG       =70         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_ROOTFOLDER        =59         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_TREEACCESS        =63         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_TREECREATE        =64         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_VISIBLE           =67         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_APP_WORKSHEETPAGES    =54         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLL_COUNT            =65808      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLL_ITEM             =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLORMAP_SET_LEVELS   =131088     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMNS_ADD           =131376     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_CATEG_MAP_GET_SORT=262543     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_CATEG_MAP_GET_SORT_LIST=262542     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_CATEG_MAP_SET_SORT_LIST=262544     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_CATEG_MAP_TYPE =262541     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_COMMENTS       =262530     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_CUSTOMDISPLAY  =262539     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_EVENSAMPLING   =262538     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_GETDATA        =262535     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_GETINFO        =262528     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_GET_EVENSAMPLING=197632     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_PARAMETER      =262532     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_ROWS           =197634     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_SETDATA        =262534     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_TEXTANDNUMERIC_SET_ALWAYS_AS_TEXT=262540     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_TYPE           =262529     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_UDL            =262537     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_COLUMN_UNITS          =262531     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_DATAOBJECTBASE_GETDATASETNAME=197104     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_DATAOBJECT_DATAFORMAT =197124     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_DATAOBJECT_DIGITMODE  =197122     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_DATAOBJECT_DIGITS     =197123     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_DATAOBJECT_DISPLAYFORMAT=197121     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_DATAOBJECT_TYPE       =197120     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_DATARANGE_ADD         =196928     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_DATARANGE_ADD_MATRIX  =196932     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_DATARANGE_ADD_SIMPLE  =196931     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_DATARANGE_GETDATA     =196930     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_DATARANGE_SETDATA     =196929     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_DATASHEET_CLEARDATA   =262691     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_DATASHEET_FINDCOL     =262693     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_DATASHEET_NUM_COLS    =262689     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_DATASHEET_NUM_ROWS    =262690     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_FOLDERS_ADD           =131120     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_FOLDERS_FINDFROMPATH  =131121     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_FOLDER_FOLDERS        =131408     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_FOLDER_PAGES          =131409     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_FOLDER_PATH           =131411     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_FOLDER_RESULTTEXT     =131410     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GLAYER_GRAPHOBJS      =196897     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GLAYER_PLOTOBJS       =196896     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHOBJECTS_ADD      =262720     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHOBJECT_DX        =262711     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHOBJECT_DY        =262712     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHOBJECT_HEIGHT    =262708     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHOBJECT_LEFT      =262705     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHOBJECT_OBJECTTYPE=262713     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHOBJECT_TEXT      =262704     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHOBJECT_TOP       =262706     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHOBJECT_WIDTH     =262707     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHOBJECT_X         =262709     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHOBJECT_Y         =262710     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_BASECOLOR   =262661     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_EXPORTADVANCED=262678     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_EXPORTAUTO  =262674     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_EXPORTCHANGERESOLUTION=262679     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_EXPORTCLIP  =262677     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_EXPORTMARGIN=262676     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_EXPORTRATIO =262675     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_EXPORTRESOLUTION=262680     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_GRADCNTRL   =262663     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_GRADCOLOR   =262662     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_HEIGHT      =262666     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_LEGENDSAUTOUPDATE=262682     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_LEGENDSFULLNAME=262681     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_LEGENDSINDICATEACTIVE=262684     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_LEGENDSMULTILAYER=262683     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_LEGENDSSYMBOLWIDTH=262685     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_PAGEVIEWMODE=262669     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_PRINTINGDPI =262671     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_PRINTINGNUMBEROFCOPIES=262672     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_PRINTINGPAPERSOURCE=262673     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_PRINTINGPRINTERNAME=262670     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_SHOWDATA    =262667     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_SHOWLABELS  =262668     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_UNITS       =262664     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_GRAPHPAGE_WIDTH       =262665     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_LAYER_ADD             =131345     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_LAYER_ADDCOPY         =131346     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_LAYER_DATAOBJS        =131344     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MATRIXOBJS_ADD        =131392     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MLAYER_DATARANGE      =262515     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MLAYER_GET_XYMAP      =262518     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MLAYER_MATOBJS        =262513     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MLAYER_NUM_MOBJTS     =262514     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MLAYER_SAVE           =262516     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MLAYER_SET_SHAPE      =262519     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MLAYER_SET_XYMAP      =262517     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MOBJ_COLORMAP         =262758     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MOBJ_COMMENTS         =262762     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MOBJ_COPY             =262753     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MOBJ_DATARANGE        =262752     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MOBJ_GETBITMAP        =262754     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MOBJ_GETDATA          =262757     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MOBJ_HAS_BITMAP       =262755     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MOBJ_SETDATA          =262756     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MOBJ_UNITS            =262761     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MOBJ_VIEWIMAGE        =262759     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_MOBJ_VIEWIMAGEOPTIONS =262760     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_NOTE_TEXT             =131440     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINFINDER_CLEAN    =262736     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINFINDER_FIND     =262739     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINFINDER_GET_METADATA=262741     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINFINDER_GET_METADATA_VAL=262742     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINFINDER_GET_OBJECT=262740     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINFINDER_LOCATIONS=262737     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINFINDER_OPTIONS  =262738     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_ACTIVATE =65853      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_DESTROY  =65842      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_DO_METHOD=65858      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_GET_NUM_PROP=65854      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_GET_STR_PROP=65855      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_INDEX    =65844      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_LONGNAME =65841      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_LTOBJVAR_GETNUM=262723     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_LTOBJVAR_GETSTR=262721     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_LTOBJVAR_SETNUM=262724     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_LTOBJVAR_SETSTR=262722     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_LT_EXEC  =65852      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_METADATA_GET=65851      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_METADATA_SET=65850      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_NAME     =65840      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_PE_PATH  =262727     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_RANGE    =262725     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_SET_NUM_PROP=65856      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_SET_STR_PROP=65857      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_SHOW     =65843      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_STG_GET  =65846      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_STG_NAMES=65845      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_STG_SET  =65847      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_THEME    =65848      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_ORIGINOBJECT_TYPE_NAME=262726     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PAGEBASE_COMMENTS     =131425     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PAGEBASE_MOVE_TO_FOLDER=131426     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PAGEBASE_TYPE         =131424     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PAGEGRAPH_GETPICTURE  =262656     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PAGEGR_ADD            =262432     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PAGELAYOUT_ADD        =262464     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PAGELAYOUT_GETPICTURE =262657     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PAGEMATRIX_ADD        =262448     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PAGENOTE_ADD          =262480     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PAGEWKS_ADD           =262416     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PAGE_LAYERS           =196880     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PAGE_PREVIEW          =196881     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PARENT                =273        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PLOTOBJECT_CHANGEDATA =262577     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PLOTOBJECT_COLORMAP   =262576     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PLOTOBJS_ADD          =131360     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PLOTOBJS_ADD_FROM_STRING=131361     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PRJINF_ORGVERSION     =131074     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_PRJINF_VERSION        =131073     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_TREENODE_CHILDREN     =131137     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_TREENODE_FIRSTCHILD   =131138     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_TREENODE_NEXTSIBLING  =131139     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_TREENODE_VALUE        =131136     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_WKS_COLUMNS           =262497     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_WKS_COPY              =262499     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_WKS_COPY_COLS_BY_PROJECT_QUERY=262491     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_WKS_DATARANGE         =262496     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_WKS_GETDATA           =262502     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_WKS_ISLABELSHOWN      =262500     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_WKS_LABELS            =262489     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_WKS_MOVE_COLUMNS      =262493     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_WKS_SAVE              =262490     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_WKS_SETDATA           =262501     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_WKS_SET_COL_DESIGNATIONS=262492     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	ODISPID_WKS_USERDEFLABEL      =262504     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0001
	IDM_PLOT_3D_SCATTER           =240        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0002
	IDM_PLOT_3D_SURFACE           =242        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0002
	IDM_PLOT_AREA                 =204        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0002
	IDM_PLOT_BOX                  =206        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0002
	IDM_PLOT_COLUMN               =203        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0002
	IDM_PLOT_CONTOUR              =226        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0002
	IDM_PLOT_HILOCLOSE            =205        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0002
	IDM_PLOT_LINE                 =200        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0002
	IDM_PLOT_LINESYMB             =202        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0002
	IDM_PLOT_SCATTER              =201        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0002
	IDM_PLOT_UNKNOWN              =230        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0002
	IDM_PLOT_XYZ_CONTOUR          =243        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0002
	IDM_PLOT_XYZ_TERNARY          =245        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0002
	ARRAY1D2D_MASK_BITS           =-16777216  # from enum __MIDL___MIDL_itf_Origin_0000_0000_0003
	ARRAY1D2D_TRANSPOSED          =33554432   # from enum __MIDL___MIDL_itf_Origin_0000_0000_0003
	ARRAY1D_DICTIONARY            =16777216   # from enum __MIDL___MIDL_itf_Origin_0000_0000_0003
	ARRAY1D_NUMERIC               =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0003
	ARRAY1D_STR                   =8          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0003
	ARRAY1D_STR_FULL_PRECISION    =10         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0003
	ARRAY1D_TEXT                  =6          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0003
	ARRAY1D_TEXT_FULL_PRECISION   =7          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0003
	ARRAY1D_VARIANT               =5          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0003
	ARRAY2D_NUMERIC               =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0003
	ARRAY2D_STR                   =9          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0003
	ARRAY2D_STR_FULL_PRECISION    =11         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0003
	ARRAY2D_TEXT                  =3          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0003
	ARRAY2D_TEXT_FULL_PRECISION   =4          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0003
	ARRAY2D_VARIANT               =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0003
	DF_BYTE                       =38         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	DF_CHAR                       =35         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	DF_COMPLEX                    =41         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	DF_DATE                       =3          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	DF_DOUBLE                     =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	DF_FLOAT                      =32         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	DF_LONG                       =34         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	DF_MONTH                      =4          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	DF_NO_CHANGE                  =-1         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	DF_SHORT                      =33         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	DF_TEXT                       =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	DF_TEXT_NUMERIC               =9          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	DF_TIME                       =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	DF_ULONG                      =40         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	DF_USHORT                     =39         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	DF_WEEKDAY                    =5          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0004
	CMTYPE_NOMINAL                =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0005
	CMTYPE_NONE                   =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0005
	CMTYPE_ORDINAL                =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0005
	OPT_EXTERNAL                  =6          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0006
	OPT_GRAPH                     =3          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0006
	OPT_LAYOUT                    =4          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0006
	OPT_MATRIX                    =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0006
	OPT_NONE                      =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0006
	OPT_NOTES                     =5          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0006
	OPT_WORKSHEET                 =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0006
	COLTYPE_ERROR                 =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0007
	COLTYPE_GROUP                 =7          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0007
	COLTYPE_LABEL                 =4          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0007
	COLTYPE_NONE                  =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0007
	COLTYPE_NO_CHANGE             =-1         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0007
	COLTYPE_SUBJECT               =8          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0007
	COLTYPE_X                     =3          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0007
	COLTYPE_X_ERROR               =6          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0007
	COLTYPE_Y                     =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0007
	COLTYPE_Z                     =5          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0007
	CREATEOPT_HIDDEN              =3          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0008
	CREATEOPT_VISIBLE             =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0008
	CREATEOPT_VISIBLE_SAME        =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0008
	STGDATAFMT_BLOB               =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0009
	STGDATAFMT_STRING             =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0009
	APPPATH_GROUP                 =3          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0010
	APPPATH_PROGRAM               =4          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0010
	APPPATH_USER                  =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0010
	MAINWND_HIDE                  =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0011
	MAINWND_SHOW                  =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0011
	MAINWND_SHOWMAXIMIZED         =3          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0011
	MAINWND_SHOWMINIMIZED         =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0011
	MAINWND_SHOW_BRING_TO_FRONT   =100        # from enum __MIDL___MIDL_itf_Origin_0000_0000_0011
	DIGITMODE_DECIMAL_DIGITS      =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0012
	DIGITMODE_FREE                =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0012
	DIGITMODE_SIGNIFICANT_DIGITS  =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0012
	COPYCTRL_ADD_LAYER_UNDOABLE   =262144     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0013
	COPYCTRL_DATA                 =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0013
	COPYCTRL_DEFAULT              =5          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0013
	COPYCTRL_IN_OPERATIONS        =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0013
	COPYCTRL_LINKED_LAYERS        =8          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0013
	COPYCTRL_MAKE_ACTIVE          =65536      # from enum __MIDL___MIDL_itf_Origin_0000_0000_0013
	COPYCTRL_NO_BINARY_STORAGE    =524288     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0013
	COPYCTRL_NO_UPDATE_CELL_LINKS =131072     # from enum __MIDL___MIDL_itf_Origin_0000_0000_0013
	COPYCTRL_OUT_OPERATIONS       =4          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0013
	PAGEVIEWMODE_DRAFT            =3          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0014
	PAGEVIEWMODE_PAGE             =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0014
	PAGEVIEWMODE_PREVIEW          =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0014
	PAGEVIEWMODE_WINDOW           =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0014
	RANGEEVENT_DATA_CHANGE        =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0015
	RANGEEVENT_SELECTION_CHANGE   =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0015
	COPYPAGE_FMT_BMP              =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0016
	COPYPAGE_FMT_DIB              =3          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0016
	COPYPAGE_FMT_EMF              =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0016
	COPYPAGE_FMT_OBJ              =4          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0016
	COPYPAGE_FMT_WMF              =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0016
	PAGEUNITS_CM                  =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0017
	PAGEUNITS_INCH                =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0017
	PAGEUNITS_LAYER               =6          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0017
	PAGEUNITS_MM                  =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0017
	PAGEUNITS_PAGE                =7          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0017
	PAGEUNITS_PIXEL               =3          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0017
	PAGEUNITS_POINT               =4          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0017
	PAGEUNITS_SCALE               =5          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0017
	GRADCTRL_COLOR_PAGE           =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0018
	GRADCTRL_TRANS_PAGE           =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0018
	GROTYPE_BEZIER                =7          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0019
	GROTYPE_CURSOR                =23         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0019
	GROTYPE_ELLIPSE               =9          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0019
	GROTYPE_LINE                  =4          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0019
	GROTYPE_POLYGON               =11         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0019
	GROTYPE_POLYLINE              =6          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0019
	GROTYPE_POLYPOLYGON           =19         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0019
	GROTYPE_RECT                  =8          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0019
	GROTYPE_TEXT                  =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0019
	LT_COMMENT                    =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0020
	LT_INVALID                    =-1         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0020
	LT_LONG_NAME                  =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0020
	LT_PARAM                      =3          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0020
	LT_SAMPLE_RATE                =13         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0020
	LT_SPARKLINE                  =14         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0020
	LT_UNIT                       =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0020
	LT_USER_DEF_LABEL             =15         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0020
	RM_HIDE_WITH_NO_FOR_ANSWER    =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0021
	RM_HIDE_WITH_YES_FOR_ANSWER   =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0021
	RM_LET_ORIGIN_DECIDE          =-1         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0021
	IMOPTS_AMPL                   =3          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0022
	IMOPTS_CURRENT                =-2         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0022
	IMOPTS_DEFAULT                =-1         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0022
	IMOPTS_IMAG                   =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0022
	IMOPTS_PHASE                  =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0022
	IMOPTS_REAL                   =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0022
	CM_SORTING_ASCENDING          =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0023
	CM_SORTING_CUSTOM             =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0023
	CM_SORTING_DESCENDING         =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0023
	CM_SORTING_UNSORTED           =-1         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0023
	STORAGE_TYPE_ALL              =3          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0024
	STORAGE_TYPE_BINARY           =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0024
	STORAGE_TYPE_INI              =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0024
	WKSC_CNTL_DATA                =4          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0025
	WKSC_CNTL_EXEC                =16         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0025
	WKSC_CNTL_IMPORT              =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0025
	WKSC_CNTL_LT_MULTILINES       =8          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0025
	WKSC_CNTL_PASTE               =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0025
	WKSC_CNTL_WKS_STRUCT          =32         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0025
	WKS_EXPORT_ALL                =2          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0026
	WKS_EXPORT_HEADING            =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0026
	WKS_EXPORT_LABELS             =4          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0026
	WKS_EXPORT_MISSING_AS_BLANK   =16         # from enum __MIDL___MIDL_itf_Origin_0000_0000_0026
	WKS_EXPORT_SELECTED           =8          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0026
	GETPICTFMT_EMF                =0          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0027
	GETPICTFMT_WMF                =1          # from enum __MIDL___MIDL_itf_Origin_0000_0000_0027
	AU_AUTO                       =1          # from enum tagAUTOUPDATEMODE
	AU_NONE                       =0          # from enum tagAUTOUPDATEMODE
	AU_ON_COMMAND                 =2          # from enum tagAUTOUPDATEMODE